//
// (c) 2006 DS Data Systems UK Ltd, All rights reserved.
//
// DS Data Systems and KonaKart and their respective logos, are 
// trademarks of DS Data Systems UK Ltd. All rights reserved.
//
// The information in this document is free software; you can redistribute 
// it and/or modify it under the terms of the GNU Lesser General Public
// License as published by the Free Software Foundation; either
// version 2.1 of the License, or (at your option) any later version.
// 
// This software is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
// Lesser General Public License for more details.
//

package com.konakartadmin.modules.shipping.ups;

import java.util.Date;

import com.konakart.util.Utils;
import com.konakartadmin.app.KKConfiguration;
import com.konakartadmin.bl.KKAdminBase;
import com.konakartadmin.modules.ShippingModule;

/**
 * UPS shipping module
 * 
 */
public class Ups extends ShippingModule
{
    /**
     * @return the config key stub
     */
    public String getConfigKeyStub()
    {
        if (configKeyStub == null)
        {
            setConfigKeyStub(super.getConfigKeyStub() + "_UPS");
        }
        return configKeyStub;
    }

    public String getModuleTitle()
    {
        return getMsgs().getString("MODULE_SHIPPING_UPS_TEXT_TITLE");
    }

    /**
     * @return the implementation filename
     */
    public String getImplementationFileName()
    {
        return "ups";
    }

    /**
     * @return an array of configuration values for this payment module
     */
    public KKConfiguration[] getConfigs()
    {
        if (configs == null)
        {
            configs = new KKConfiguration[14];
        }

        if (configs[0] != null && !Utils.isBlank(configs[0].getConfigurationKey()))
        {
            return configs;
        }

        Date now = KKAdminBase.getKonakartTimeStampDate();
        int groupId = 6;
        int i = 0;
        configs[i++] = new KKConfiguration(
        /* title */"Enable UPS Shipping",
        /* key */"MODULE_SHIPPING_UPS_STATUS",
        /* value */"True",
        /* description */"Do you want to offer UPS shipping?",
        /* groupId */groupId,
        /* sort Order */i,
        /* useFun */"",
        /* setFun */"tep_cfg_select_option(array('True', 'False'),",
        /* dateAdd */now);

        configs[i++] = new KKConfiguration(
        /* title */"Tax Class",
        /* key */"MODULE_SHIPPING_UPS_TAX_CLASS",
        /* value */"0",
        /* description */"Use the following tax class on the shipping fee.",
        /* groupId */groupId,
        /* sort Order */i,
        /* useFun */"tep_get_tax_class_title",
        /* setFun */"tep_cfg_pull_down_tax_classes(",
        /* dateAdd */now);

        configs[i++] = new KKConfiguration(
        /* title */"Shipping Zone",
        /* key */"MODULE_SHIPPING_UPS_ZONE",
        /* value */"0",
        /* description */"If a zone is selected, only enable this shipping method for that zone.",
        /* groupId */groupId,
        /* sort Order */i,
        /* useFun */"tep_get_zone_class_title",
        /* setFun */"tep_cfg_pull_down_zone_classes(",
        /* dateAdd */now);

        configs[i++] = new KKConfiguration(
        /* title */"Sort Order",
        /* key */"MODULE_SHIPPING_UPS_SORT_ORDER",
        /* value */"0",
        /* description */"Sort order of display.",
        /* groupId */groupId,
        /* sort Order */i,
        /* useFun */"",
        /* setFun */"",
        /* dateAdd */now);

        configs[i++] = new KKConfiguration(
        /* title */"UPS Access License Number",
        /* key */"MODULE_SHIPPING_UPS_LICENSE_NUMBER",
        /* value */"",
        /* description */"Your UPS access license number for using the service.",
        /* groupId */groupId,
        /* sort Order */i,
        /* useFun */"",
        /* setFun */"",
        /* dateAdd */now);

        configs[i++] = new KKConfiguration(
        /* title */"Request URL",
        /* key */"MODULE_SHIPPING_UPS_URL",
        /* value */"https://onlinetools.ups.com/ups.app/xml/Rate",
        /* description */"The URL where the XML request is sent",
        /* groupId */groupId,
        /* sort Order */i,
        /* useFun */"",
        /* setFun */"",
        /* dateAdd */now);

        configs[i++] = new KKConfiguration(
        /* title */"UPS UserId",
        /* key */"MODULE_SHIPPING_UPS_USERID",
        /* value */"",
        /* description */"The UPS UserId for using the service",
        /* groupId */groupId,
        /* sort Order */i,
        /* useFun */"",
        /* setFun */"",
        /* dateAdd */now);

        configs[i++] = new KKConfiguration(
        /* title */"UPS Password",
        /* key */"MODULE_SHIPPING_UPS_PASSWORD",
        /* value */"",
        /* description */"The UPS password for using the service",
        /* groupId */groupId,
        /* sort Order */i,
        /* useFun */"",
        /* setFun */"",
        /* dateAdd */now);

        configs[i++] = new KKConfiguration(
                /* title */"Return quote for a defined service code",
                /* key */"MODULE_SHIPPING_UPS_RATE_OR_SHOP",
                /* value */"False",
                /* description */"Set to true in order to choose a single rate. Set to false to shop for all available rates",
                /* groupId */groupId,
                /* sort Order */i,
                /* useFun */"",
                /* setFun */"tep_cfg_select_option(array('True', 'False'),",
                /* dateAdd */now);

        configs[i++] = new KKConfiguration(
                /* title */"UPS Service code",
                /* key */"MODULE_SHIPPING_UPS_SERVICE_CODE",
                /* value */"",
                /* description */"Only used if we want a single quote for a defined service code. In this case it defines the service code that we want.",
                /* groupId */groupId,
                /* sort Order */i,
                /* useFun */"",
                /* setFun */"",
                /* dateAdd */now);
        
        configs[i++] = new KKConfiguration(
                /* title */"UPS Service codes to exclude",
                /* key */"MODULE_SHIPPING_UPS_SERVICE_CODES_EXCLUDE",
                /* value */"",
                /* description */"Comma separated list of service codes that will be excluded from the quotes returned to the customer (i.e. 01,07,12).",
                /* groupId */groupId,
                /* sort Order */i,
                /* useFun */"",
                /* setFun */"",
                /* dateAdd */now);
               
        configs[i++] = new KKConfiguration(
                /* title */"Measurement Unit",
                /* key */"MODULE_SHIPPING_UPS_MEASUREMENT_UNIT",
                /* value */"LBS",
                /* description */"Should be set to KGS or LBS",
                /* groupId */groupId,
                /* sort Order */i,
                /* useFun */"",
                /* setFun */"",
                /* dateAdd */now);
        
        configs[i++] = new KKConfiguration(
                /* title */"Packaging type by weight",
                /* key */"MODULE_SHIPPING_UPS_PACKAGING_TYPE",
                /* value */"1000:00",
                /* description */"Example (10:25,25:24,1000:00): weight 5-10 = box code 25; weight 10-25 = box code 24 etc.",
                /* groupId */groupId,
                /* sort Order */i,
                /* useFun */"",
                /* setFun */"",
                /* dateAdd */now);
        
        configs[i++] = new KKConfiguration(
                /* title */"Handling Fee",
                /* key */"MODULE_SHIPPING_UPS_HANDLING",
                /* value */"0",
                /* description */"Handling fee for this shipping method",
                /* groupId */groupId,
                /* sort Order */i,
                /* useFun */"",
                /* setFun */"",
                /* dateAdd */now);

        return configs;
    }
}
